@@ -3,7 +3,8 @@ from hydenv.measurements import HydenvMeasurementsCli
 from hydenv.exercises import HydenvExercises
 from hydenv.backend import run as backend_run
 
-from hydenv.scripts.hobo_import import HydenvHoboImporter
+from hydenv.scripts.hobo_import import HydenvHoboImporterCli
+from hydenv.scripts.examples import HydenvExamplesCli
 
 
 import fire
@@ -11,6 +12,9 @@ fire.Fire({
     'database': HydenvDatabase,
     'measurements': HydenvMeasurementsCli,
     'exercises': HydenvExercises,
+    'exercise': HydenvExercises,
     'backend': backend_run,
-    'hobo': HydenvHoboImporter
+    'hobo': HydenvHoboImporterCli,
+    'example': HydenvExamplesCli,
+    'examples': HydenvExamplesCli
 })
